/*
 * Copyright 2019 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.ars.ars.
 *
 * de.bsvrz.ars.ars is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.ars.ars is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.ars.ars.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */
package de.bsvrz.ars.ars.mgmt.tasks;

import de.bsvrz.dav.daf.main.DataState;
import de.bsvrz.dav.daf.main.archive.ArchiveDataKind;
import de.bsvrz.sys.funclib.kappich.annotations.Nullable;
import de.bsvrz.sys.funclib.losb.util.Util;

/**
 * Klasse, die einen Archivdatensatz mit den zugehoerigen Zeitstempeln und Datenindex kapselt.
 */
class SimpleArchiveData {

    /**
     * Zeitstempel / Datenindex
     */
    public final long arcTime;
    public final long dataTime;
    public final long dataIdx;

    /**
     * Datensatzart
     */
    public final ArchiveDataKind dataKind;

    /**
     * Zustand des Datensatzes (Datensatztyp).
     */
    public final DataState dataState;

    /**
     * serialisierter Datensatz
     */
    public final byte[] rawData;

    /**
     * komprimiert?
     */
    public final boolean compressed;

    /**
     * Erstellt ein neues SimpleArchiveData mit den angegebenen Werten.
     *
     * @param arcTime    Archivzeit
     * @param dataTime   Datenzeit
     * @param dataIdx    Datenindex
     * @param dataKind   Datensatzart
     * @param dataState  Datensatztyp
     * @param compressed Flag, das besagt, ob der Datensatz komprimiert ist.
     * @param rawData    Datensatz
     */
    public SimpleArchiveData(
            long arcTime, long dataTime, long dataIdx, ArchiveDataKind dataKind, DataState dataState, boolean compressed, @Nullable byte[] rawData) {
        this.arcTime = arcTime;
        this.dataTime = dataTime;
        this.dataIdx = dataIdx;
        this.dataKind = dataKind;
        this.dataState = dataState;
        this.rawData = rawData;
        this.compressed = compressed;
    }

    public String toString() {
        return "dx=" + Util.dIdx2StrExt(dataIdx) + " (" + dataIdx + ")  dt=" + Util.timestrMillisFormatted(dataTime) + "  at="
                + Util.timestrMillisFormatted(arcTime) + "  " + dataKind + "  " + dataState;
    }
}
