/*
 * Copyright 2020 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.ars.ars.
 *
 * de.bsvrz.ars.ars is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.ars.ars is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.ars.ars.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */
package de.bsvrz.ars.ars.mgmt.tasks;

import de.bsvrz.dav.daf.main.DataState;
import de.bsvrz.dav.daf.main.archive.ArchiveDataKind;
import de.bsvrz.dav.daf.util.fileBackedQueue.QueueSerializer;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

/**
 * TBD Dokumentation
 */
public enum SimpleArchiveDataSerializer implements QueueSerializer<SimpleArchiveData> {

    Instance {
        @Override
        public int getSize(SimpleArchiveData object) {
            final byte[] rawData = object.rawData;
            int dataLength;
            if(rawData == null) {
                dataLength = 0;
            }
            else {
                dataLength = rawData.length;
            }
            return 8+8+8+1+1+1+4+dataLength;
        }

        @Override
        public void serialize(DataOutputStream outputStream, SimpleArchiveData object) throws IOException {
            outputStream.writeLong(object.arcTime);
            outputStream.writeLong(object.dataTime);
            outputStream.writeLong(object.dataIdx);
            outputStream.writeByte(object.dataKind.getCode());
            outputStream.writeByte(object.dataState.getCode());
            outputStream.writeBoolean(object.compressed);
            final byte[] rawData = object.rawData;
            if(rawData != null) {
                outputStream.writeInt(rawData.length);
                outputStream.write(rawData);
            }
            else {
                outputStream.writeInt(-1);
            }
        }

        @Override
        public SimpleArchiveData deserialize(DataInputStream inputStream) throws IOException {
            long arcTime = inputStream.readLong();
            long dataTime = inputStream.readLong();
            long dataIdx = inputStream.readLong();
            int dataKindCode = inputStream.readByte();
            int dataStateCode = inputStream.readByte();
            boolean compressed = inputStream.readBoolean();
            int length = inputStream.readInt();
            byte[] rawData = null;
            if(length != -1) {
                rawData = new byte[length];
                inputStream.readFully(rawData);
            }
            return new SimpleArchiveData(
                    arcTime,
                    dataTime,
                    dataIdx,
                    ArchiveDataKind.getInstance(dataKindCode),
                    DataState.getInstance(dataStateCode),
                    compressed,
                    rawData
            );
        }
    }

}
