/*
 *
 * Copyright 2017-2020 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.ars.ars.
 *
 * de.bsvrz.ars.ars is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.ars.ars is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.ars.ars.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.ars.ars.persistence.walk.internal;

import de.bsvrz.ars.ars.mgmt.datatree.DataIdentNode;
import de.bsvrz.ars.ars.persistence.DataIdentificationDir;
import de.bsvrz.ars.ars.persistence.PersistenceManager;

import java.util.Iterator;

/**
 * Iterator über alle Containerverzeichnisse im Archivsystem
 *
 * @author Kappich Systemberatung
 */
public class ParameterizedContainerDirs implements DataIdentificationDirGetter {

	/**
	 * Eigenschaft _iterator vom Typ Iterator&lt;DataIdentNode&gt;
	 */
	private final Iterator<DataIdentNode> _iterator;

	/**
	 * Persistenzmanager
	 */
	private final PersistenceManager _persMgr;

	/**
	 * Erstellt eine neue AllContainerDirs-Instanz
	 */
	public ParameterizedContainerDirs(final PersistenceManager persMgr) {
		_iterator = persMgr.getArchiveManager().getDataIdentTree().iterator();
		_persMgr = persMgr;
	}

	@Override
	public DataIdentificationDir poll() {
	    if(_iterator.hasNext()) {
	    	return new DataIdentificationDir(_persMgr, _iterator.next());
	    }
	    return null;
	}
}
